local Main = SCGStatus
local Me = {}
Main.Status = Me

-------------------------------------------------------------------------------
local STATUS_DEFS = {
	"+ On Duty";
	"+ Standby";
	"- Off Duty";
}

-------------------------------------------------------------------------------
local players = {}
local playerGuildMap = {}

-------------------------------------------------------------------------------
-- Fetch data from the guild roster.
--
function Me.Update()
	players = {}
	playerGuildMap = {}
	for i = 1, GetNumGuildMembers() do
		local fullName,rank,rankIndex,_,_,_,note,note2,online = GetGuildRosterInfo( i )
		local name = Ambiguate( fullName, "all" )
		if online then
		
			-- a little bit of magic...~ 
			if rank == "Officer" and note2:lower():match( "^captain" ) then
				rank = "Captain"
				rankIndex = rankIndex - 0.5
			end
			
			players[name] = {
				rank       = rank;
				rank_index = rankIndex;
				status     = note;
				rname      = note2;
			}
		end
		playerGuildMap[name] = i
	end
end

-------------------------------------------------------------------------------
-- Returns true if the player is an officer (should have admin capability).
--
function Me.IsOfficer()
	local guildName, _, guildRankIndex = GetGuildInfo( "player" )
	if guildName ~= "Stormwind City Guard" then return false end
	return CanEditOfficerNote()
end

-------------------------------------------------------------------------------
-- Get current status from guild roster.
--
-- @param name Name of player or nil for self.
-- @returns Status text, on duty, clean status string (prefixed with +/- and space)
--          player rank, player rank index.
function Me.Get( name )
	name = name or UnitName( "player" )
	local data = players[name]
	if not data then return end
	
	local status, onduty = Me.Parse( data.status )
	local clean
	if onduty then
		clean = "+ " .. status
	else
		clean = "- " .. status
	end
	
	return status, onduty, clean, data.rank, data.rank_index, data.rname
end

function Me.Parse( status )
	if status:sub(1,1) == "+" then
		return status:gsub( "^%+%s*", "" ), true
	elseif status:sub(1,1) == "-" then
		return status:gsub( "^%-%s*", "" ), false
	end
	return status, false
end

-------------------------------------------------------------------------------
-- Returns true if a status is not defined in the standard status selection.
--
function Me.IsCustom( status )
	for k,v in pairs( STATUS_DEFS ) do
		if v == status then
			return false
		end
	end
	
	return true
end

-------------------------------------------------------------------------------
-- Get current status from guild roster.
--
-- @param status Status to set.
-- @param name Name of player or nil for self.
--
function Me.Set( status, name )
	
	name = name or UnitName( "player" )
	name = Ambiguate( name, "all" )
	
	if not Main.InGuild() then 
		return
	end
	if name ~= UnitName("player") and not Me.IsOfficer() then return end
	
	if not playerGuildMap[name] then return end -- player is not in guild...
	
	GuildRosterSetPublicNote( playerGuildMap[name], status )
end

-------------------------------------------------------------------------------
-- Returns true if a player is on duty.
--
-- @param name Name of player or nil for self.
--
function Me.OnDuty( name )
	name = name or UnitName( "player" )
	name = Ambiguate( name, "all" )
	if not players[name] then return end
	return players[name].status:sub( 1, 1 ) == "+"
end

-------------------------------------------------------------------------------
function Me.GetAll()
	return players
end

-------------------------------------------------------------------------------
-- Returns list of standard status settings.
--
function Me.List()
	return STATUS_DEFS
end
